
<!-- TRW AUTO-GENERATED — do not edit between markers -->
<!-- trw:start -->

{{imperative_opener}}
{{ceremony_quick_ref}}
{{memory_harmonization}}
{{framework_reference}}
{{delegation_section}}
{{agent_teams_section}}
{{behavioral_protocol}}
{{rationalization_watchlist}}
{{ceremony_phases}}
{{ceremony_table}}
{{ceremony_flows}}
{{architecture_section}}
{{conventions_section}}
{{categorized_learnings}}
{{patterns_section}}
{{adherence_section}}
{{closing_reminder}}
<!-- trw:end -->
